@@ -546,12 +546,12 @@ impl<O: IsA<Service>> ServiceExtManual for O {
             let user_data: Box_<glib::thread_guard::ThreadGuard<P>> =
                 Box_::new(glib::thread_guard::ThreadGuard::new(callback));
             unsafe extern "C" fn store_trampoline<P: FnOnce(Result<(), glib::Error>) + 'static>(
-                _source_object: *mut glib::gobject_ffi::GObject,
+                source_object: *mut glib::gobject_ffi::GObject,
                 res: *mut gio::ffi::GAsyncResult,
                 user_data: glib::ffi::gpointer,
             ) {
                 let mut error = ptr::null_mut();
-                let _ = ffi::secret_service_store_finish(_source_object as *mut _, res, &mut error);
+                let _ = ffi::secret_service_store_finish(source_object as *mut _, res, &mut error);
                 let result = if error.is_null() {
                     Ok(())
                 } else {
@@ -1032,7 +1032,7 @@ impl<O: IsA<Service>> ServiceExtManual for O {
             let mut item_paths = item_paths.to_string();
             ffi::secret_service_get_secrets_for_dbus_paths(
                 self.as_ref().to_glib_none().0,
-                &mut item_paths as *mut _ as *mut *const i8,
+                &mut item_paths as *mut _ as *mut *const libc::c_char,
                 cancellable.map(|p| p.as_ref()).to_glib_none().0,
                 Some(callback),
                 Box_::into_raw(user_data) as *mut _,
